package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!`````"9```````!``````````$BS````
M`````````$``.``-`$``'``;``8````$````0`````````!``$```````$``
M0```````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#0```````&`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````*`:````````H!H`````````
M$`````````$````%`````"``````````($`````````@0```````/3X`````
M```]/@`````````0`````````0````0`````8`````````!@0````````&!`
M``````#H10```````.A%`````````!`````````!````!@```&BM````````
M:+U```````!HO4```````*@$`````````!4`````````$`````````(````&
M````>*T```````!XO4```````'B]0```````,`(````````P`@````````@`
M````````!`````0````X`P```````#@#0```````.`-```````!`````````
M`$``````````"``````````$````!````'@#````````>`-```````!X`T``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`T```````#@#0```````0`````````!```````````@`````````4.5T9`0`
M``!`GP```````$"?0```````0)]```````#D`````````.0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````:*T```````!HO4```````&B]0```
M````F`(```````"8`@````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`(MI+6=U0HQ>`YM:C.NY\K95-3QX!````!`````!````1TY5```````#
M`````@``````````````$0```$D````$````"````"`0$``%0`2$*`(``("&
M`("""0``"2`$"(B@$$6Z``((`````$D```!,````3P```%````!6````5P``
M`%@```!:````6P````````!=````7@```%\```!@``````````````!NQ=\?
MSMY'+6M_FGPNQ9NV(/_D#M5DU'S9<5@<XD?&`:Q+X\"ZXY)\PN4_+/JA;&"S
M`8MO:PE#UF>OS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;X:<""J/@
M^TD``````````````````````````````````````0$``!(`````````````
M````````````N`$``!(`````````````````````````$@(``!(`````````
M````````````````\`$``!(``````````````````````````0```"``````
M````````````````````&0(``!(`````````````````````````F`(``!(`
M````````````````````````I````!(`````````````````````````+@(`
M`!(`````````````````````````<P$``!(`````````````````````````
M;`(``!(`````````````````````````@@(``!(`````````````````````
M````=````!(`````````````````````````DP,``!(`````````````````
M````````_````!(`````````````````````````40(``!(`````````````
M````````````0P(``!(``````````````````````````0(``!(`````````
M````````````````D0(``!(`````````````````````````;0(``!(`````
M````````````````````K@(``!(`````````````````````````\0```!$`
M````````````````````````5P$``!(`````````````````````````TP``
M`!$`````````````````````````)0$``!(`````````````````````````
ML@```!(`````````````````````````H0$``!(`````````````````````
M````Y0$``!(`````````````````````````^`$``!(`````````````````
M````````_P(``!(`````````````````````````C@$``!(`````````````
M````````````)P(``!(`````````````````````````LP$``!(`````````
M````````````````XP(``!(`````````````````````````]@(``"$`````
M````````````````````W`(``!(`````````````````````````,P$``!(`
M````````````````````````H0(``!(`````````````````````````'0``
M`"``````````````````````````]P(``!$`````````````````````````
M90(``!(`````````````````````````5````!(`````````````````````
M````T0$``!(`````````````````````````F@$``!(`````````````````
M````````@P```!(`````````````````````````CP```!(`````````````
M````````````3`$``!(`````````````````````````$@$``!(`````````
M````````````````1@```!(`````````````````````````!@$``!(`````
M````````````````````=`(``!(`````````````````````````@P$``!(`
M````````````````````````X````!(`````````````````````````'P(`
M`!(`````````````````````````K`$``!(`````````````````````````
MS0(``!(`````````````````````````M0(``!(`````````````````````
M````90$``!(`````````````````````````8P```!(`````````````````
M````````U0(``!(`````````````````````````/`(``!(`````````````
M````````````Q````!(`````````````````````````0P$``!(`````````
M````````````````]0(``!$`````````````````````````ZP$``!(`````
M````````````````````R0$``!(`````````````````````````5P(``!(`
M````````````````````````+````"``````````````````````````-0(`
M`!(`````````````````````````2@(``!(`````````````````````````
MB@(``!$`````````````````````````OP(``!(`````````````````````
M````G`,``!(`#@!`74```````%X`````````R`,``!(`#@"`3D```````/@*
M````````\`(``!(`#@#@(T```````"`"````````<`,``!(`#@!@1$``````
M``4`````````1P0``!(`#@!P1$```````/(!````````=`0``!(`#@"`64``
M`````+4#````````,P0``!``&0`0PD``````````````````KP,``!(`#@!P
M1D```````"4`````````X@,``!$`$```8$````````0`````````(00``!``
M&0!HTD``````````````````/P0``!(`#@`00T```````#,`````````5`0`
M`!(`#@!P34````````L!````````9@0``!(`#@#03$```````'0`````````
MU0,``!``&`#PP4``````````````````O`,``!(`#@"@1D```````.0`````
M````J`,``!``&``0PD``````````````````%P0``!$`&``(PD````````@`
M````````8`,``!(`#@`07D````````4`````````!P0``!(`#@"@74``````
M`&4`````````VP,``!(`#@``)D```````"\`````````UP,``"``&`#PP4``
M````````````````@0,``!(`#@!034```````!T`````````\0,``!(`#@"@
M0T```````+\`````````)@0``!(`#@"01T```````#X%`````````%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F
M971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC
M;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!L<W1A=#8T`%]?<W1R;F-P
M>5]C:&L`;W!E;F1I<@!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y
M7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A
M8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E
M9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O+C4N,S(N,`!L:6)D;"YS;RXR`&QI
M8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QI8F-R>7!T+G-O
M+C$`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A<E]B87-E
M;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])
M3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U
M7VEN:70`;7E?<&%R7W!L`%]E;F0`<&%R7VEN:71?96YV`%]?8G-S7W-T87)T
M`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E
M;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,BXU`$=,
M24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`$=,
M24)#7S(N,S,`+W5S<B]L:6(V-"]P97)L-2\U+C,R+C$O>#@V7S8T+7!L9"UL
M:6YU>"UT:')E860M;75L=&DO0T]210`````"``,``@`"`````@`"`````@``
M``0``@````(````"``(`!0`"``0``@`````````````````#``(`!@````(`
M`P`"``(``@````<````"``@````#``(`````````````````!P```````@`#
M``(``@```````@`"```````"``(``P`'`````@`"``(`!P`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0```````0`!
M`#@#```0````(````'4::0D```,`B@0````````!``8`2`,``!``````````
ME)&6!@``"`"6!```$````'09:0D```<`H00``!````!R&6D)```&`*T$```0
M````%&EI#0``!0"Y!```$````+.1E@8```0`PP0``!````!U&FD)```"`(H$
M````````J+]````````&````!0``````````````L+]````````&````"@``
M````````````N+]````````&````%@``````````````P+]````````&````
M&```````````````R+]````````&````(@``````````````T+]````````&
M````)P``````````````V+]````````&````*```````````````X+]`````
M```&````,```````````````Z+]````````&````.P``````````````\+]`
M```````&````1```````````````^+]````````&````1P``````````````
M&,!````````'`````0``````````````(,!````````'`````@``````````
M````*,!````````'`````P``````````````,,!````````'````!```````
M````````.,!````````'````!@``````````````0,!````````'````!P``
M````````````2,!````````'````"```````````````4,!````````'````
M"0``````````````6,!````````'````"P``````````````8,!````````'
M````#```````````````:,!````````'````#0``````````````<,!`````
M```'````#@``````````````>,!````````'````#P``````````````@,!`
M```````'````$```````````````B,!````````'````$0``````````````
MD,!````````'````$@``````````````F,!````````'````$P``````````
M````H,!````````'````%```````````````J,!````````'````%0``````
M````````L,!````````'````%P``````````````N,!````````'````&0``
M````````````P,!````````'````&@``````````````R,!````````'````
M&P``````````````T,!````````'````'```````````````V,!````````'
M````'0``````````````X,!````````'````'@``````````````Z,!`````
M```'````'P``````````````\,!````````'````(```````````````^,!`
M```````'````(0```````````````,%````````'````)```````````````
M",%````````'````)0``````````````$,%````````'````)@``````````
M````&,%````````'````*0``````````````(,%````````'````*@``````
M````````*,%````````'````*P``````````````,,%````````'````+```
M````````````.,%````````'````+0``````````````0,%````````'````
M+@``````````````2,%````````'````+P``````````````4,%````````'
M````,0``````````````6,%````````'````,@``````````````8,%`````
M```'````,P``````````````:,%````````'````-```````````````<,%`
M```````'````-0``````````````>,%````````'````-@``````````````
M@,%````````'````-P``````````````B,%````````'````.```````````
M````D,%````````'````.0``````````````F,%````````'````.@``````
M````````H,%````````'````/```````````````J,%````````'````/0``
M````````````L,%````````'````/@``````````````N,%````````'````
M/P``````````````P,%````````'````00``````````````R,%````````'
M````0@``````````````T,%````````'````0P``````````````V,%`````
M```'````10``````````````X,%````````'````1@``````````````Z,%`
M```````'````2```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!<&?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S__T%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E
M*````$B)1"0H,<#H)_[__TB+-<";``!(BSW!FP``2(GRZ/$Y``!(BP6*FP``
M@#@`#X0O`0``3(LE<IL``$&+/"3H`?[__T&+/"2`B#H$```"Z/']__^`B#H$
M```!BT0D'(UX!4AC_TC!YP/H5_W__TB+?"003&-$)!S'!<.M```$````2(G!
M2(D%L:T``$B+!TV)P4B)`4B-!2$]``!(B4$(2,?`",)``$B+`$B)01!(C04+
M/0``2(E!&+@!````08/X`7X8D$B+-,>-4`-(@\`!2&/22(DTT4PYP'7I08U1
M`TB+/6ZM``!%,<!(C354'@``2&/"2,<$P0````#HQ/W__T&)Q(7`#X2,````
M2(L]0JT``$B-;"0DZ#C\__\QP$B)[DB-/6\[``#HUQ<``$B%P'1Y2(L]&ZT`
M`.BF^___Z%']__](BT0D*&1(*P0E*`````^%C@```$B#Q#A$B>!=05S#Z!W\
M__](B07FK```2(G'2(7`='3H2?O__TR+)2J:``!!BSPDZ+G\___&@.D)````
MZ:/^__](BSVVK```Z,']__]!B<3I8/___TB+/9JL``!(A?]T"NAX-P``Z7'_
M__](C3V$.@``2(GNZ#07``!(B05UK```2(G'2(7`#X1/____Z]+H*OO__[\!
M````Z(#]___S#Q[Z,>U)B=%>2(GB2(/D\%!42<?`$%Y``$C'P:!=0`!(Q\?@
M(T``_Q6:F0``])#S#Q[ZPV8N#Q^$``````"02(T]R9L``$B-!<*;``!(.?AT
M%4B+!4Z9``!(A<!T"?_@#Q^``````,,/'X``````2(T]F9L``$B--9*;``!(
M*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%59D``$B%P'0(_^!F#Q]$``###Q^`
M`````(`]:9L```!U%U5(B>7H?O___\8%5YL```%=PP\?1```PV9F+@\?A```
M````#Q]``.N.9BX/'X0```````\?0`!!5TR-3SA!5D%505154TB![)@"``!D
M2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=!F+@\?A```````08L!
M28LQ28/`$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(P>@H2,'N."4`_P``2`GP
M2(G.2,'A"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-.=!UKDB-L@`"```/'X``
M````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)U
MU4R+#TR+7Q!(BW<@2(M?&$R)R$R)RDB+;PA(P>H;2,'@!4@)T`,$)(V4,)EY
M@EI,B=A(BW0D"$@QV$@AZ$B-M#.9>8):2#'81(T4`DB)ZDB)Z$C!Z`)(P>(>
M38G02`G"3(G82<'H&XG12#'(3"'(3#'82`'P3(G62,'F!4P)QD2--#!,B<Y,
MB<A(P>8>2,'H`DV)\$@)\$B+="002<'H&T@QPD&)Q4PATDF-M#.9>8):2#'*
M2`'R3(GV2,'F!4P)QD2-!#),B=9)P>H"2(M4)!A(P>8>3`G62(V4$9EY@EI,
MB<%(,?!!B?1,(?!,,>A(P>D;2`'03(G"2,'B!4@)RDR)\4G![@)(P>$>1(T4
M$$B)\$B+5"0@3`GQ3(G62#'(28V4%9EY@EI(P>X;08G.3"'`3#'@2`'03(G2
M2,'B!4@)\D2-+!!,B<))P>@"2(M$)"A(P>(>3(GN3`G"28V$!)EY@EI(P>X;
M2#'108G03"'13#'Q2`'!3(GH2,'@!4@)\$2-)`%,B=!)P>H"2(M,)#!(P>`>
M3(GF3`G028V,#IEY@EI(,<)!B<),(>I,,<)(`<I,B>%(P>$%2,'N&T@)\4R)
M[DG![0)(P>8>1(TT"DB+5"0X3`GN3(GQ2#'P28V4$)EY@EI(P>D;08GU3"'@
M3#'02`'03(GR2,'B!4@)RDR)X4G![`)(P>$>1(T$$$B)\$B+5"1`3`GA3(G&
M2#'(28V4$IEY@EI(P>X;08G,3"'P3#'H2`'03(G"2,'B!4@)\D2-%!!,B?))
MP>X"2(M$)$A(P>(>3(G63`GR28V$!9EY@EI(P>X;2#'108G63"'!3#'A2`'!
M3(G02,'@!4@)\$2-+`%,B<!)P>@"2(M,)%!(P>`>3(GN3`G`28V,#)EY@EI(
MP>X;2#'"08G`3"'23#'R2`'*3(GI2,'A!4@)\4R)UDG!Z@)(P>8>1(TD"DB+
M5"183`G63(GA2#'P28V4%IEY@EI(P>D;08GR3"'H3#'`2`'03(GB2,'B!4@)
MRDR)Z4G![0)(P>$>1(TT$$B)\$B+5"1@3`GI3(GV2#'(28V4$)EY@EI(P>X;
M08G-3"'@3#'02`'03(GR2,'B!4@)\D2-!!!,B>)(BT0D:$C!XAY)P>P"3(G&
M3`GB28V$`IEY@EI(P>X;2#'108G43"'Q3#'I2`'!3(G`2,'@!4@)\$2-%`%,
MB?!)P>X"2(M,)'!(P>`>3(G63`GP28V,#9EY@EI(P>X;2#'"08G&3"'"3#'B
M2`'*3(G12,'A!4@)\4R)QDG!Z`)(P>8>1(TL"DB+5"1X3`G&3(GI2#'P28V4
M%)EY@EI(P>D;08GP3"'03#'P2`'03(GJ2,'B!4@)RDR)T4G!Z@)(P>$>1(TD
M$$B)\$B+E"2`````3`G13(GF2#'(28V4%IEY@EI(P>X;08G*3"'H3#'`2`'0
M3(GB2,'B!4@)\D2--!!,B>I)P>T"2(N$)(@```!(P>(>3(GV3`GJ28V$`)EY
M@EI(P>X;2#'108G53"'A3#'12`'!3(GP2,'@!4@)\$2-!`%,B>!)P>P"2(N,
M))````!(P>`>3`G@28V,"IEY@EI-B<)(,<))P>H;B<9,(?),,>I(`<I,B<%(
MP>$%3`G138GR2<'N`DG!XAZ)R4T)\D@!RDB+C"28````3#'008G43"'`28V,
M#9EY@EI-B>5(,?!)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G!2<'H`DC!X1Y!
MB<5,"<%-B=!%B=),`Y0DJ````$DQR$0QPDR+A"2@````3HV$!J'KV6Y,B>Y)
M`=!,B>I(P>X;2,'B!4@)\HG220'03(GB2<'L`DC!XAY$B<9,">))B<R)R4@#
MC"2P````23'41#'@28GT38V4`J'KV6Y(B?!)P>P;2,'@!4P)X(G`20'"3(GH
M2<'M`DC!X!Y%B=1,">A)B=6)TDDQQ44QZ$V)Y4@#E"2X````3HV$`:'KV6Y,
MB>%)P>T;2,'A!4P)Z8G)3`'!28GP2,'N`DG!X!Y!B<U)"?!(B<:)P$@#A"3`
M````3#'&03'R2HVT$J'KV6Y,B>I-B>I)P>H;2,'B!4P)THG22`'R3(GF2<'L
M`DC!YAY!B=),">9-B<1%B<!,`X0DR````$DQ]$0QX4V)U$B-C`BAZ]EN3(G0
M2<'L&TC!X`5,">")P$@!R$R)Z4G![0)(P>$>08G$3`GI28GUB?9),<U$,>I-
MB>5-C800H>O9;DR)XDC!X@5)P>T;2`.T)-````!,">J)TDD!T$R)TDG!Z@)(
MP>(>18G%3`G228G*B<E(`XPDV````$DQTD0QT$V)ZDB-M`:AZ]EN3(GH2<'J
M&TC!X`5,"=")P$@!QDR)X$G![`)(P>`>08GR3`G@28G4B=)(`Y0DX````$DQ
MQ$4QX$V)U$Z-A`&AZ]EN3(G12<'L&TC!X05,">&)R4P!P4V)Z$G![0))P>`>
M08G,30GH28G%B<!-,<5$,>Y-B>5(C;0RH>O9;DR)XDG![1M(P>(%3`GJB=)(
M`?),B=9)P>H"2`.$).@```!(P>8>08G53`G638G"18G`3`.$)/````!),?)$
M,=%-B>I(C8P(H>O9;DR)Z$G!ZAM(P>`%3`G0B<!(`<A,B>%)P>P"2,'A'D&)
MPDP)X4F)](GV2`.T)/@```!),<Q$,>)-B=1-C800H>O9;DR)TDG![!M(P>(%
M3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDF)S8G)23'51#'H38GE2(VT!J'K
MV6Y,B>!)P>T;2,'@!4P)Z(G`2`'&3(G02,'@'DG!Z@)!B?5(`XPD``$``$P)
MT$F)THG22`.4)`@!``!),<)%,=!-B>I.C80!H>O9;DR)Z4G!ZAM(P>$%3`G1
MB<E,`<%-B>!)P>P"2<'@'D&)RDT)X$F)Q(G`2`.$)!`!``!-,<1$,>9-B=1(
MC;0RH>O9;DR)TDG![!M(P>(%3`GBB=)(`?),B>Y)P>T"2,'F'D&)U$P)[DV)
MQ46)P$DQ]40QZ4V)Y4B-C`BAZ]EN3(G@2<'M&TC!X`5,">B)P$@!R$R)T4G!
MZ@)(P>$>08G%3`G128GR3`.$)!@!``")]DDQRD@#M"0@`0``1#'238VT$*'K
MV6Y,B>I-B>A)P>@;2,'B!4P)PDF)R(G)2`.,)"@!``")TDD!UDR)XDG![`)(
MP>(>18GR3`GB23'01#'`3(VD!J'KV6Y,B=!,B=9(P>X;2,'@!4@)\$B)UHG2
M2`.4)#`!``")P$D!Q$R)Z$G![0)(P>`>18G@3`GH2#'&03'V3(G&3HVL,:'K
MV6Y,B<%(P>X;2,'A!4@)\8G)20'-3(G12<'J`DC!X1Y$B>Y,"=%)B<*)P$DQ
MRD4QU$@#A"0X`0``3HV4(J'KV6Y(B?))B?1)P>P;2,'B!4P)XDV)Q$G!Z`))
MP>0>00'230G$28G(B<E-,>!$B>)%,<5.C80HH>O9;DR)T$V)U4G![1M(P>`%
M3`GH3(NL)$`!``!%C30`28GP2,'N`DR)X$G!X!Y)"?!$B<9,"<!,(=!)(?1)
M"<2XW+P;CTD!Q4P!Z4V)]4P!X4V)]$G![1M)P>0%30GL00',3(G12<'J`DC!
MX1Y,"=%)"<A)B<U!B<I-(?!)(?5-">A,BZPD2`$``$D!Q4P!ZDV)Y4D!T$R)
MXDG![1M(P>(%3`GJ18TL$$R)\DG![@)(P>(>3`GR28G.08G020G632'F3"'!
M3`GQ3(NT)%`!``!)`<9,`?9-B>Y(`?%,B>Y)P>X;2,'F!4P)]D2--#%,B>9)
MP>P"2,'F'DP)YD@)\DF)](GQ32'$3"'J3`GB3(ND)%@!``!)`<1-`>)-B?1,
M`=)-B?))P>(%2<'L&TT)XD:-)!)-B>I)P>T"2<'B'DT)ZDF)]42)TDT)U4TA
M]4@AUDP)[DR+K"1@`0``20'%30'H38GE3`'&38G@2<'M&TG!X`5-">A&C2P&
M38GP2<'N`DG!X!Y-"?!-"<)-B<9$B<9)(=9-(>)-"?),B[0D:`$``$D!QDP!
M\4V)[DD!RDR)Z4G![AM(P>$%3`GQ18TT"DR)X4G![`)(P>$>3`GA38G$20G,
M08G*32'L32'030G@3(ND)'`!``!)`<1,`>)-B?1)`=!,B?))P>P;2,'B!4P)
MXD6-)!!,B>I)P>T"2,'B'DP)ZD@)T4F)U4&)T$TAU4PA\4P)Z4R+K"1X`0``
M20'%3`'N38GE2`'Q3(GF2<'M&TC!Y@5,">Y$C2PQ3(GV2<'N`DC!YAY,"?9)
MB=:)\4D)]DTAYD@ARDP)\DR+M"2``0``20'&30'R38GN3`'238GJ2<'N&TG!
MX@5-"?)&C30238GB2<'L`DG!XAY-">),"=9-B=1$B=))(<Q,(>Y,">9,BZ0D
MB`$``$D!Q$T!X$V)]$P!QDV)\$G![!M)P>`%30G@1HTD!DV)Z$G![0))P>`>
M30GH38G51(G&30G%32'U22'R30GJ3(NL))`!``!)`<5,`>E-B>5)`<I,B>%)
MP>T;2,'A!4P)Z46-+`I,B?%)P>X"2,'A'DP)\4D)R$F)SD&)RDDA]DTAX$T)
M\$R+M"28`0``20'&3`'R38GN20'03(GJ2<'N&TC!X@5,"?)%C3003(GB2<'L
M`DC!XAY,">))B<Q!B=!)"=1-(>Q,(<%,">%,BZ0DH`$``$D!Q$P!YDV)]$@!
M\4R)]DG![!M(P>8%3`GF1(TD,4R)[DG![0)(P>8>3`GN2`GR28GUB?%-(<5,
M(?),">I,BZPDJ`$``$D!Q4T!ZDV)Y4P!TDV)XDG![1M)P>(%30GJ1HTL$DV)
M\DG![@))P>(>30GR28GV1(G230G632'F2"'63`GV3(NT)+`!``!)`<9-`?!-
MB>Y,`<9-B>A)P>X;2<'@!4T)\$:--`9-B>!)P>P"2<'@'DT)X$T)PDV)Q$2)
MQDDAU$TAZDT)XDR+I"2X`0``20'$3`'A38GT20'*3(GQ2<'L&TC!X05,">%%
MC20*3(GI2,'A'DG![0),">E-B<5!B<I)"<U-(?5-(=!-">A,BZPDP`$``$D!
MQ4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ18TL$$R)\DG![@)(P>(>3`GR2`G1
M28G008G732'03"'A3`G!3(N$),@!``!)`<!,`<9-B>A(`?%,B>Y)P>@;2,'F
M!4P)QD2-!#%,B>9)P>P"2(G12,'F'DP)YD&)]$@)\4PAZ4PAXD@)RDB+C"30
M`0``2`'!2`.$)-@!``!)`<I,B<%)`<=,`=)-B<)(P>$%2<'J&TP)T8G)2`'*
M3(GI2<'M`DC!X1Y!B=),">E,B=!("<Y)B<U(P>`%08G.32'E3"'&3`GN38G5
M2<'M&TP!_DP)Z(G`2`'&3(G`2<'H`DC!X!Y!B?5)"<"XUL%BRDPQP3'*2(N,
M).`!``!(`<%,`>%-B>Q(`=%,B>I)P>P;2,'B!4P)XHG22`'13(G22<'J`DC!
MXAY!B<Q)"=),B<)%B<!,,=(QUDB+E"3H`0``2`'"20'63(GB3`'V38GF2,'B
M!4G![AM,"?*)TDR--!9,B>I)P>T"3(G62,'B'D6)]T6)TDD)U4B+E"3P`0``
M3#'N2`'",?%,B?Y,`<)(P>X;2`'13(GZ2,'B!4@)\DB+M"3X`0``B=)(`=%,
MB>)(`<9)P>P"2,'B'DP!UDV)ZD&)R$P)XDV)Q$6)[4DQTD4QUDZ-%#9,B<9(
MP>8%2<'L&TP)YHGV20'R3(G^2<'O`DC!YAY%B=1)"?=(B[0D``(``$@!QDP!
M[DF)U8G233']1#'I3(TL#DR)X4R)YDC![AM(P>$%2`GQ3(G&2<'H`HG)2,'F
M'DD!S4B+C"0(`@``3`G&38GX23'P18GN18G_2`'!13'"2`'*3(GQ3HT$$DR)
M\DC!Z1M(P>(%2`G*2(GQB?:)TDD!T$R)XDG![`)(P>(>18G"20G42(N4)!`"
M``!,,>%(`<)!,<U,B=%,`?I)`=5,B=)(P>D;2,'B!4@)RDR)\4G![@*)TDC!
MX1Y)`=5(BY0D&`(``$P)\46)[T@!PD@!\DR)YD6)Y$@QSD$Q\$R)_DD!T$R)
M^DC![AM(P>(%2`GRB=))`=!,B=))P>H"2,'B'D6)QDD)TDB+E"0@`@``3(GV
M2,'N&T@!PDP!XDF)S(G)33'413'E3HTD*DR)\DC!X@5("?)(B[0D*`(``(G2
M20'43(GZ2`'&2<'O`DC!XAY%B>5,"?I(`?%,B=9%B=)(,=9!,?!,B>Y)`<A,
MB>E(P>X;2,'A!4@)\8G)20'(3(GQ2<'N`DC!X1Y%B<=)"<Y(BXPD,`(``$R)
M_DC![AM(`<%,`=%)B=*)TDTQ\D4QU$Z-%"%,B?E(P>$%2`GQ3(GN2<'M`HG)
M2,'F'DD!RDB+C"0X`@``3`GN18G42`'!2`'*3(GQ18GV2#'Q03'(3(GA20'0
M3(GB2,'I&TC!X@5("<I(B?&)]HG220'03(GZ2,'B'DG![P)%B<5)"==(BY0D
M0`(``$PQ^4@!PD$QRDR)Z4P!\DC!Z1M)`=),B>I(P>(%2`G*3(GA2<'L`HG2
M2,'A'DD!TDB+E"1(`@``3`GA18G\18G62`'"2`'R3(G^2#'.03'P2HTT`DR)
M\DV)\$G!Z!M(P>(%3`G"B=)(`=9,B>I)P>T"2,'B'D&)\$D)U4B+E"10`@``
M2`'"3`'B28G,B<E-,>Q%,>).C2023(G"38G"2<'J&TC!X@5,"=*)TDD!U$R)
M\DG![@)(P>(>18GB3`GR3(NT)%@"``!)`<9,`?%-B>Y%B>U),=9$,?9-B=9(
M`<Y,B=%)P>X;2,'A!4P)\8G)2`'.3(G!2<'H`DC!X1Y!B?9)"<A(BXPD8`(`
M`$@!P4D!S4B)T8G23#'!03',2XU,)0!-B?1-B?5)P>T;2<'D!4T)[$V)U4G!
MZ@))P>4>18GD30GJ3(NL)&@"``!,`>%!B<Q)`<5,`>I-B<5%B<!-,=5$,>Y,
MC2PR3(GB3(GF2,'B!4C![AM("?*)TDD!U4R)\DG![@)(P>(>1(GN20G62(N4
M)'`"``!(`<)(`X0D>`(``$P!PDV)T$TQ\$0QP4F)\$@!RDB)\4G!Z!M(P>$%
M3`G!18G0`=%,B>))P>P"2,'B'DD)U$J-%`A(B<A)`=!,B?)(P>`%1`'C3#'B
M2(E?&$$QU4N-%"A)B<@!Z4G!Z!M(B4\(3`G``=!(B0=(B?!(P>X"2,'@'D@)
MQD$!\T0#=R!,B5\03(EW($B+A"2(`@``9$@K!"4H````=1)(@<28`@``6UU!
M7$%=05Y!7\/H%.3__P\?0`!!5T%6055!5%532(/L"$B%_P^$L0```$B+!:J"
M``!,BRA-A>T/A)X````/M@=)B?](B?6$P'0$/#UU544Q]DV+90!-A>1T+TUC
M]DR)ZP\?`$R)\DR)_DR)Y^CRXO__A<!U!T.`/#0]=$=,BV,(2(/#"$V%Y'7:
M2(/$"$R)X%M=05Q!74%>05_##Q^$``````!)B?Y!#[9&`4F#Q@&$P'0$/#UU
M[T4I_NN5#Q^``````$PIZT^-9#0!2,'[`XE=`.NU#Q^``````$4QY.NI#Q\`
M059!54%455-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]
M=3%(BX0DF````&1(*P0E*`````^%*0$``$B!Q*````!;74%<05U!7L-F+@\?
MA```````Z'OB__])B<1(A<!TPDF)Y4R)Y^C(Y/__2(7`#X2O````@'@3+DB-
M6!-U#8![`0!TWP\?@`````"`>!,N#X2F````2(GOZ(;B__](B=])B<;H>^+_
M_T&-?`8"2&/_Z+[C__])B=E)B>B^`0```$F)QDB)QS'`2,?"_____TB-#4$A
M``#H".7__TR)]TR)[NAMXO__3(GW@_C_=!"+1"08)0#P```]`$```'1=Z&#A
M__],B??H..'__TR)Y^@@Y/__2(7`#X58____#Q^``````$R)Y^B8XO__2(GO
MZ.#A___IZO[__P\?`(![`2X/A5#___^`>P(`#X04____Z4'___\/'X``````
MZ)/^___KH>C,X?__9F8N#Q^$``````"054B)_4B![*````!D2(L$)2@```!(
MB80DF````#'`2(GFZ"KA__^%P'4VBU0D&('B`/```('Z`$```'0(@?H`H```
M=1Z^`@```$B)[^B/X___A<`/E,`/ML#K!P\?1```,<!(BXPDF````&1(*PPE
M*````'4)2('$H````%W#Z#WA__]F9BX/'X0``````&:005:Z_P\``$%5051)
MB?152(G]2(T]`2```$B![!@0``!D2(L$)2@```!(B80D"!```#'`28GE3(GN
MZ%+@__^%P'Y.C5#_3&/R0H`\-``/A7T```"%TG0Y3(GROB\```!,B>_HB>'_
M_TB%P'0D2(L%57\``(LXZ.;A__],B?%,B>I(B>Y(B<?HY>+__^L?#Q\`2(L%
M,7\``(LXZ,+A__],B>)(B>Y(B<?HU.#__TB+A"0($```9$@K!"4H````=1E(
M@<08$```74%<05U!7L-FD$QC\.E_____Z%/@__\/'P!!5T%6055!5%5(B?53
M2(G[2(/L*&1(BP0E*````$B)1"08,<`QP(`^/0^4P$@!Q4B)[^@)X/__2(UT
M)!1(B=])B<0QP.CW^___2(7`#X0&`0``2(G'28G%Z./?__]).<0/AM(```!,
M8W0D%$R+/99^``!)P>8##[8#A,`/A)\!```\/0^$EP$``$B)V`\?0``/ME`!
M2(/``832=`6`^CUU[T@IV$B82HU\(`)-`S?HW>#__TF)!DB%P'1628L'2&-4
M)!1(C4L!2(L4T`^V`X@"A,!T(3P]=0SK&V8/'T0``(3`=!$/M@%(@\(!2(/!
M`8@"/#UUZ\8"/3'`9@\?1```#[9,!0"(3`(!2(/``83)=>](BT0D&&1(*P0E
M*`````^%#P$``$B#Q"A;74%<05U!7D%?PP\?0``QP&8/'T0```^V5`4`08A4
M!0!(@\`!A-)U[NN]#Q]``$R+/:E]``!-BP=)@S@`#X2[````3(G`13'M9@\?
M1```2(/`"$2)ZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP77CP``A<!U6TB)]TR)
M1"0(QP7!CP```0```.C<W___2(7`#X14____3(M$)`A-8_5(B<=)P>8#3(GR
M3(G&Z&G@__])B0=(B<%!C44!2)A(QP3!`````$2);"04Z8'^__\/'P!,B<?H
M(.#__TF)!TB)P4B%P`^$`O___TUC]4G!Y@/KQ0\?A```````,<#I?_[__[X0
M````13'MZ5_____H%][__P\?@`````!(@^P(2(L%G7P``(LXZ"[?__](BQ6'
M?```2(/$"$B-#=Q;``!(B<=(C37;'```Z4W?__]F9BX/'X0``````&:04TB+
M'6!\``"+.^CQWO__2(G'Z*G___^+.^CBWO__3(T%,!X``$4QR5M(Q\*`64``
M2(G'3(G!2(TUJ!P``.E.W___9F8N#Q^$```````/'P!!5%532('L("```&1(
MBP0E*````$B)A"08(```,<!(B>5,C:0D$!```.C2W/__3(T-0!P``+H!$```
M2(GO08G`2(T-8QP``+X!````,<#HW=___[H`$```3(GF2(GOZ'W<__]%,<"%
MP'@NC7@!2(G#2&/_Z$C>__])B<!(A<!T&$ACVTR)YDB)QTB)VNC_W?__Q@08
M`$F)P$B+A"08(```9$@K!"4H````=0](@<0@(```3(G`6UU!7,/HP=S__Y#I
M.____V9F+@\?A```````05=!5D%528GU05152(G]2(T]TAL``%-(@>RX$```
M9$B+!"4H````2(F$)*@0```QP$B-="0,Z&7X__^^+P```$B)[TB)P^B5W/__
M2(7`=$`QP$B)[DB-/94;``#H__O__TB)Z$B+G"2H$```9$@K'"4H````#X5R
M`0``2('$N!```%M=05Q!74%>05_##Q\`2(GOZ`C<__](C35?&P``3(GO08G$
MZ#;>__])B<9(A<!TGD&`/@!,C2TI&P``#X39````#Q]$``!(A=MT$TR)]DB)
MW^BXW/__A<`/A)@```!,B??HN-O__XU0_XG!2&/"3`'P@#@O=1L/'X0`````
M`(G1@^H!Q@``2&/"3`'P@#@O=.U"C40A`3W_#P``#X\M____N@`0``!-B?"^
M`0```#'`3(V\)*````!(@^P(2(T-H1L``%5,C0VS&@``3(G_Z`O>__](C70D
M($R)_^ANV___6EF%P'40BT0D*"4`\```/0"```!T2$B--7\:```Q_^A:W?__
M28G&2(7`#X2^_O__08`^``^%+/___TB%VW0%@#LN=!)-B>ZY`0```.E@____
M#Q]$``"`>P$`=+KKYKX!````3(G_Z`/=__^%P'6G3(G^2(T]%AH``.B`^O__
M3(G_Z%C=___I=_[__^B^VO__9F8N#Q^$```````/'P`/M@=)B?B$P'079@\?
M1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N#Q^$``````!(A?\/A,\```!5
M@#\`2(G]#X2J````Z%7:__](C50%_T@YU7(4Z:,```!F#Q]$``!(@^H!2#G5
M="6`.B]T\D@YU0^#A@```$B#Z@%(.=5T#H`Z+W0H2(/J`4@YU77R@'T`+W1<
M2(T]91D``%WIG]S__P\?@`````"`.B]U"4B#Z@%(.=5R\D@IZC'`2(U*`DB!
M^0`0``!W'TB#P@&Y`!```$B)[DB-/?5Z``#H<-O__TB-!>EZ``!=PP\?@```
M``!(C3WO&```7>E#W/__2#G5=:OKB@\?0`!(C3W7&```Z2S<__]F9BX/'X0`
M`````)!54TB-'=D8``!(@^Q(9@]O!7M7``!D2(L$)2@```!(B40D.#'`,<!(
MC6PD#`\11"009@]O!6=7``!FB40D,`\11"0@#Q]$```QP$B)[DB)W^@K]?__
M2(7`=#Y(BP7G=P``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'4P8``"0,<!(B>Y(B=_HT_3__TB%
MP'0^2(L%CW<``$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1W\%P``9@\?A```````,<!(B>Y(B=_H
M<_3__TB%P'0^2(L%+W<``$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)TSP\?@```
M``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1VE%P``9@\?A```````,<!(
MB>Y(B=_H$_3__TB%P'0^2(L%SW8``$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)T
MSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1U,%P``9@\?A```
M````,<!(B>Y(B=_HL_/__TB%P'0^2(L%;W8``$AC5"0,2(L`2(T$T$B+4`A(
MB1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1W\%@``
M9@\?A```````,<!(B>Y(B=_H4_/__TB%P'0^2(L%#W8``$AC5"0,2(L`2(T$
MT$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(
MC1U1%@``9@\?A```````,<!(B>Y(B=_H\_+__TB%P'0^2(L%KW4``$AC5"0,
M2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$``!(C1U(%@``9@\?A```````,<!(B>Y(B=_HD_+__TB%P'0^2(L%3W4`
M`$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%
MTG7PZ[9F#Q]$``!(C1WR%0``9@\?A```````,<!(B>Y(B=_H,_+__TB%P'0^
M2(L%[W0``$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$``!(C1V<%0``9@\?A```````,<!(B>Y(B=_HT_'_
M_TB%P'0^2(L%CW0``$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(
MBU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1W:%```9@\?A```````,<!(B>Y(
MB=_H<_'__TB%P'0^2(L%+W0``$AC5"0,2(L`2(T$T$B+4`A(B1!(A=)TSP\?
M@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(B>Y(C3WC%```Z"'Q__](
MB<9(A<!T#DB-/;L4```QP.C+]/__2(GN2(T]SQ0``#'`Z/KP__](B<9(A<!T
M#DB-/<L4```QP.BD]/__2(GN2(T]Q10``#'`Z-/P__](B<9(A<!T.DB-/0P4
M```QP.A]]/__,<!(C37+%```2(T],!0``.AH]/__2(M$)#AD2"L$)2@```!U
M44B#Q$A;7<-(B>Y(C3V"%```,<#H@/#__TB)QDB%P'002(T]$!0``#'`Z"KT
M___KJTBX4$%27T-,14%(.40D(76:9H%\)"E./7612(UT)"OKS^A2U/__9I!(
M@^P89$B+!"4H````2(E$)`B+!1AU``"#^/]T&TB+?"0(9$@K/"4H````=4)(
M@\08PV8/'T0``$B-="0$2(T]FQ,``#'`Z/7O__](B<(QP$B%TG02#[82@/HP
M#Y7!,<"$T@^5P"'(B07#=```ZZ[HW-/__V9F+@\?A```````D$B#[`CHU]/_
M_XG'Z(#3__](A<!T`TB+`$B#Q`C##Q\`05152(G]2(T]*!0``%-(@^P09$B+
M!"4H````2(E$)`@QP$B-="0$Z'3O__](A<!T"(`X`$B)PW4W2(M$)`AD2"L$
M)2@````/A;D```!(B>Y(@\002(T]VA,``#'`6UU!7.GZ\O__9BX/'X0`````
M`$B)[DB)Q^C5U?__2(7`="!(BT0D"&1(*P0E*````'5V2(/$$%M=05S##Q^`
M`````$B)[^CXTO__2(G?28G$Z.W2__])C7P$`N@SU/__2(/L"$F)Z+X!````
M4TC'PO____](B<=)B<1,C0T@$@``2(T-`1,``#'`Z'35__]86DB+1"0(9$@K
M!"4H````=0A,B>;I2O___^BETO__#Q]$``!!5TF)_TB-/<P1``!!5D%50515
M4TB![)B!``!D2(L$)2@```!(B80DB($``$B-!8(2``!,C6PD+$C'1"1`````
M`$C'A"28`````````$R)[DC'1"1@`````$B)1"0P2(T%<1$``$B)1"0X2(T%
M^!$``$B)1"1X2(T%/1(``$B)A"2`````2(T%^A$``$B)A"2(````2(T%)Q(`
M`$B)A"20````2(T%'!(``$B)1"18,<#HVNW__TB%P'0,@#@`2(G%#X69!```
M,<#H`O[__TB)Q4B%P`^$Y@,``$B)[^BNT?__2(U\``'H]-+__T0/MD4`2(G#
M183`=#Y)B=Y,C27,$0``#Q]$``!%#[;`3(GW3(GAO@$```!(Q\+_____,<!(
M@\4!28/&`N@CU/__1`^V10!%A,!UT4R-9"1P2(T]+1$``.L5#Q\`28M\)`A)
M@\0(2(7_#X0V`0``3(GN,<#H+.W__TB)Q4B%P'3<@#@`=-=(B<?H9^___X7`
M=,M(B>_HJ]/__TF)QDB%P`^$_P````\?@`````!,B??H\-#__TB)WTB)Q>CE
MT/__1(VD!00$``!-8^1,B>?H(M+__U-,C0TJ$```38GP2(G%2(T%"A$``+X!
M````2,?"_____U!(C0WM$```2(GO,<#H7]/__[[``0``2(GOZ/+/__]!6$%9
M@_C_=1+HM,___T2+"$&#^1$/A1L#``!,C;0DH````$B)[TR)]N@$T/__B<.%
MP`^$N@```$B+!3MO``!)BP])B>A%,>1(C15#$0``O@$```!(BS@QP.C$TO__
M2(N$)(B!``!D2"L$)2@````/A8`(``!(@<28@0``3(G@6UU!7$%=05Y!7\,/
M'X0``````$B+;"0P13'DZQ-F#Q]$``!)8\1(BVS$,$B%[70[@'T``'0U2(GO
M08/$`>@A[O__A<!TW4B)[^AETO__28G&2(7`#X7!_O__26/$2(MLQ#!(A>UU
MR0\?0`!%,?;IJ/[__XN$)+@````E`/```#T`0```#X4O____BX0DO````(D$
M).B:S___.00D#X47____BX0DN````"7_`0``/<`!```/A0#___],B>?HHM#_
M_TB-/9T/``!,B>Y)B<0QP.@^Z___2(G'2(7`#X1"`@``Z,W1__])BS](B<;H
M@O+__TF)Q4B%P`^$)@(``$R)[^@.S___@_@#?D%(8]"Y!0```$B-/5$/``!)
MC705_/.F#Y?"@-H`A-)U(8/X!`^$\`4``(/H!4B808!\!0`O#X3?!0``#Q^`
M`````#'`Z('Z__^%P'45,?9,B>_HH]#__T&)QX7`#X7``0``2(TUN`X``$B-
M/3D.```QP.A3[O__3(TM(0\``$R-->4-``#H$,[__T%528GHO@$```!02,?"
M_____TR)YS'`3(T-P@T``$B-#<L.``#H%M'__UA:ZT-FD.A[S?__@S@1=4GH
MT<W__X/#`4B#[`A-B?%!54F)Z$B-#:D.``!,B>=32,?"_____[X!````4#'`
MZ-/0__](@\0@OL`!``!,B>?H8LW__X/X_W2M2(GOZ!7-__],B>9(C3TS#0``
M,<#HI.W__TR)Y^@\^O__Z:/]__\/'X``````2(T]X@T``#';ZQ(/'T0``$AC
MPTB+?,102(7_=#A,B>XQP(/#`>BFZ?__2(7`=.&`.`!TW$B)Q^@TT/__2(G%
M2(7`#X72^___2&/#2(M\Q%!(A?]UR+\-````2(TMC0T``.BZSO__0;A3````
M2(G#Z<7[__](BP4];```28L/28GH13'D2(T5!0X``+X!````2(LX,<#HQL__
M_^G]_/__D$B)Q^B(^?__2(N$)(B!``!D2"L$)2@````/A70%``!(@<28@0``
M2(GO6UU!7$%=05Y!7^F8S___#Q^$``````!-BR_ITOW__[H"````2,?&[O__
M_XG'Z%7/__](C80D@`$``+H&````1(G_2(G&2(D$).B9S?__@+PD@`$```!U
M#H"\)($!``!##X2#!```,=(Q]D2)_^@5S___N(FKS>](QX0DH`````$C16=(
MB80DJ````$@MB\X25TB)A"2P````2`7R!!@K2(F$),````!(C80DV````$C'
MA"2X````=E0R$$C'A"3(`````````$C'A"30`````````,>$)!@!````````
M2(E$)!@/'T``2(LT)+H`@```1(G_Z._,__](B<%!B<"%P`^.70$``$B+O"3(
M````2(N4)-````!(8\%(BQPDC33/2#G^2(FT),@```!(@](`2,'H'4@!T$AC
ME"08`0``2(F$)-````"%T@^%J0```$&#^#\/C@$#``!!C4#`B40D%,'H!D2-
M:`&)1"0(2<'E!DD!W0\?1```\P]O"_,/;U,03(GW2(/#0/,/;UO@\P]O8_`/
M$8PDV`````\1E"3H````#Q&<)/@````/$:0D"`$``.@QT?__3#GK=;R+1"0(
M1(M$)!3!X`9!*<!(BWPD&$ECT+E(````3(GN1(E$)`CH,\S__T2+1"0(1(F$
M)!@!``#I\?[__Y!!N4````!(BT0D&$B+-"1(B4PD"$$IT40YR4B-/!!$#T[)
M26/92(G:Z`/,__^+A"08`0``2(M,)`@!V(/X0(F$)!@!```/A:7^__]!B<A,
MB?=!*=A(`QPD1(E$)`CHCM#__T2+1"0(Z>O^__]$B?_H+,O__TB+A"3(````
MBYPDR````$2+K"30````2,'H`P_+@^`_00_-C4@!2)C&A`38````@(/Y.`^.
MO0$``+I`````2&/Q2`-T)!@IRG0/,<")P8/``<8$#@`YT'+S3(GWZ!O0__]F
M#^_`2,>$)`@!````````#Q&$)-@````/$80DZ`````\1A"3X````3(GW1(FL
M)!`!``!,C;PD,0$``$R-M"1X`0``B9PD%`$``$R-+2D*``#HQ<___TB+A"2@
M````#[>4)*````!)B<!(P>@0B(0D,0$``&;!P@A)P>@8BX0DJ````&:)E"0R
M`0``#\B)A"0T`0``BX0DL`````_(B80D.`$``(N$)+@````/R(F$)#P!``"+
MA"3`````#\B)A"1``0``2(V$)%`!``!(B00D2(G#ZPYF#Q]$``!%#[8'28/'
M`4B)WT4/ML!,B>F^`0```$C'PO____\QP$B#PP+H]\O__TDYWG722(T%P`D`
M`,:$)'@!````4/]T)`A(C0UX"0``28GH3(GG,<"^`0```$R-#6,(``!(Q\+_
M____Z+?+__]97NGS^O__38M_"$V%_P^$&_K__TR)_^C;R/__2(/X`P^&"?K_
M_TF-=`?\N04```!(C3T<"0``\Z8/E\`<`(3`30]$[^GF^?__28G=Z6G]__^Z
M.````$ACP3'_2`-$)!@IRH/Z"',P]L($#X77````A=(/A&S^___&``#VP@(/
MA&#^__\Q_V:)?!#^Z53^__\/'X``````B=%(QP``````2,=$"/@`````2(U(
M"$B#X?A(*<@!T(/@^(/X"`^"(O[__X/@^#'2B=:#P@A(B3PQ.<)R\^D+_O__
M@+PD@@$``$$/A6_[__^`O"2#`0``0P^%8?O__X"\)(0!``!(#X53^___@+PD
MA0$``$4/A47[__^Z`@```$C'QL;___]$B?_H4LK__TB+'"2Z*0```$2)_TB)
MWNB>R/__2(T%3`@``%!3Z9+^___'``````#'1!#\`````.F*_?__Z*C'__\/
M'X0``````$%7059!54%455-(@^PH3(LE(V8``&1(BP0E*````$B)1"08,<!,
MC7PD%$&+/"3HG<C__T&+/"1(B</HD<C__P^VD[@```!,B?Y(C3W#!@``B)"Y
M````,<#H,^/__TB%P'0)@#@Q#X3-`@``,<#HGNW__T&+/"3H5<C__[D+````
MN@$```!(C363!P``2(G'Z/S'__](A<`/A,0```!(BT`0@STH>````4R+<"@/
MCJ\````QV^LY9BX/'X0``````$B+=A!(BQ7]=P``26/%2(L\PNBIQ___08G`
MBP7P=P``187`=7&#Q0)$B>LYQ7UG08L\)(G=1(UK`>C2Q___,<E(8]-,B?9(
MB<?HHLC__TB%P'0]2(LPBT8,)0`$(``]``0``'2;08L\)$B)="0(Z)W'__](
MBW0D"+D"````,=)(B<?HN<;__TB)QNEU____D(L%>G<``(U0_SG3#X1O`0``
M08L\).AFQ___N0,```"Z`0```$B--:D&``!(B<?H#<?__TB)PTB%P'0S2(M`
M$$&+/"1(BRCH-<?__TB-%80&``!(B<=(B>[H0\;__TB+0Q!(BRCV10Y`#X6\
M`0``08L\).@)Q___N0,```"Z`0```$B--5,&``!(B<?HL,;__TB)PTB%P'0[
M3(G^2(T][P0``#'`Z)?A__])B<5(A<`/A$L!``!(BT,008L\)$B+*.B[QO__
M3(GJ2(G'2(GNZ,W%__]!BSPDZ*3&__^Z`0```$B--?4%``!(B<?HL,;__T&+
M/"1(B<7HA,;__TB-%>\%``!(B>Y(B<?HDL7__T&+/"3H:<;__TR)_DB-/6<$
M``#&@+D`````,<#H$>'__TB)!5)V``!)B<1(A<!T>K[``0``3(GGZ%7$__^-
M4`&#^@%V"8/X$0^%[````$B+1"089$@K!"4H````#X73````2(/$*%M=05Q!
M74%>05_#D(/X`0^.B/[__[L!````9I!!BSPD@\,!Z.3%__],B?9(B<?H&<3_
M_SD=TW4``'_AZ5W^__\/'T``2(L]N74``.CL\?__2(D%O74``$F)Q$B%P`^%
M9____TB-/;H%```QP.C+Q?__#Q\`@'@!``^$,/W__^DD_?__9@\?A```````
M2(L%<74``$&+/"1,BRA(BT,02(LHZ&;%__],B>Y(B>_H^^+__^FI_O__08L\
M).A-Q?__2(GN2(G'Z*+%___I*_[__^@(Q/__B<%(BP4G=0``3(GB2(T]904`
M`$B+,#'`Z$O%__]F9BX/'X0``````%5(B?U32(/L".A2Z?__2(G'Z!KI__](
MB<,QP.AP[___A<!T)4B%[70@@'T``'0:N00```!(C3WB`P``2(G>\Z8/E\`<
M`(3`=`=(@\0(6UW#2(/$"$B)[UM=Z4+@__]FD/,/'OI!5TR-/;M?``!!5DF)
MUD%528GU051!B?Q52(TMK%\``%-,*?U(@^P(Z"_"__](P?T#=!\QVP\?@```
M``!,B?),B>Y$B>=!_Q3?2(/#`4@YW77J2(/$"%M=05Q!74%>05_#9F8N#Q^$
M``````#S#Q[ZPV8N#Q^$``````"0\P\>^DB+#<UC``#ID,/___,/'OI(@^P(
M2(/$",,`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#4`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$;
M`SOD````&P```."`__\H`0``H(3__P`&``#`AO__``$``/"&__\4`0``L(?_
M_U`!``#0G?__H`$``*">___L`0``(*#__S`"``"PH/__5`(``)"A__^0`@``
MT*/__]P"```0I/__]`(``&"D__\0`P``(*7__T0#```PI?__6`,``#"G__^X
M`P``8*?__\P#``!0J/___`,``)"M__\H!```$*[__T0$```PKO__7`0``$"O
M__^L!```0+K__X`%````OO__S`4``&"^__\P!@``T+[__W@&``#@OO__D`8`
M```````4``````````%Z4@`!>!`!&PP'")`!```0````'````+B%__\O````
M`$0'$!`````P````U(7__P4`````````)````$0```"P?___P`,````.$$8.
M&$H/"W<(@``_&CLJ,R0B`````$P```!L````6(;__QP6````0@X0CP)&#AB.
M`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0!0/W%0H..$$.,$$.*$(.($(.&$(.
M$$(."$$+````2````+P````HG/__S0````!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`$`````(
M`0``K)S__W0!````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP
M00XH00X@0@X80@X00@X(2PL`(````$P!``#HG?__@P````!!#A"&`DH.L`$"
M<0H.$$$."$$+.````'`!``!4GO__W0````!"#A".`D<.&(T#0@X@C`1$#BB&
M!5$.P"`"I@H.*$$.($(.&$(.$$(."$,+2````*P!``#XGO__.0(```!"#A"/
M`D(.&(X#0@X@C01"#BB,!4$.,(8&1`XX@P='#F`#%0$*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A%"Q0```#X`0``[*#__S,`````1`X060X(`!@````0`@``%*'_
M_T(`````00X0@P)H#@@````P````+`(``$BA__^_`````$(.$(P"00X8A@-!
M#B"#!$<.P$`"IPH.($0.&$$.$$(."$$+$````&`"``#4H?__!0````````!<
M````=`(``-"A___R`0```$(.$(\"0@X8C@-"#B"-!$4.*(P%00XPA@9+#CB#
M!T<.\"$"9`H..$$.,$$.*$(.($(.&$(.$$(."$0+`JX.^"%(#H`B70[X(4$.
M\"$````0````U`(``'"C__\E`````````"P```#H`@``C*/__^0`````2@X0
MA@("8@K&#@A,"P)`"@X(2`M("L8."$4+2PX(QB@````8`P``3*3__SX%````
M00X0A@)!#AB#`TL.8`/?!`H.&$$.$$$."$$+&````$0#``!@J?__=`````!$
M#B!M"@X(1PL``!0```!@`P``Q*G__QT`````1`X06`X(`$P```!X`P``S*G_
M_PL!````0@X0C`)!#AB&`TL.((,$1`XP`D(*#B!*#AA!#A!"#@A/"V0*#B!!
M#AA!#A!"#@A("V$..$D.0&,..$$.,```T````,@#``",JO__^`H```!"#A"/
M`DP.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M"#`@.D`0[8@P)A#N"#`F`.
MV(,"0@[0@P(">`H..$0.,$$.*$(.($(.&$(.$$(."$D+`X(!#MB#`DD.X(,"
M8`[8@P)!#M"#`EH.V(,"10[@@P).#NB#`DT.\(,"2P[0@P(#!0$*#CA$#C!!
M#BA"#B!"#AA"#A!"#@A-"P/.`P[8@P)$#N"#`F@.V(,"00[0@P(#/P$*#MB#
M`D$.X(,"10L```!(````G`0``+BT__^U`P```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T0.8`.V`@H..$$.,$$.*$(.($(.&$(.$$(."$(+,```
M`.@$```LN/__7@````!!#A"&`D0.&(,#1`X@`D0*#AA!#A!!#@A!"T0.&$0.
M$$$.""P````<!0``F'[__R`"````0@X0C`)!#AB&`T0.4`.``0H.&$0.$$(.
M"$$+`````$0```!,!0``*+C__V4`````1@X0CP))#AB.`T4.((T$10XHC`5$
M#C"&!D@..(,'1PY`;@XX00XP00XH0@X@0@X80@X00@X(`!0```"4!0``4+C_
M_P4``````````````!````"L!0``2+C__Q``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````.`F0```````L"9````````!````````
M`!$#`````````0`````````C`P````````$`````````+@,````````!````
M`````#@#`````````0````````!(`P````````$`````````4@,````````/
M`````````,X$````````#```````````($````````T`````````,%Y`````
M```9`````````&B]0```````&P`````````(`````````!H`````````<+U`
M```````<``````````@`````````]?[_;P````#``T````````4`````````
ML`U````````&`````````)@$0```````"@`````````)!0````````L`````
M````&``````````5`````````````````````P``````````P$````````(`
M````````B`4````````4``````````<`````````%P`````````8%4``````
M``<`````````$!1````````(``````````@!````````"0`````````8````
M`````/[__V\`````@!-```````#___]O``````(`````````\/__;P````"Z
M$D``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!XO4`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0````````````````````````````/____\`````V&)```````!'
M0T,Z("A03$0M3&EN=7@I(#$P+C,N,"`R,#(Q,#0P."`H<F5L96%S92D``"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````!@#0```````&`,`````
M```<`````````````````````0```````````````````!,````'`````@``
M```````X`T```````#@#````````0`````````````````````@`````````
M```````````F````!P````(`````````>`-```````!X`P```````"0`````
M```````````````$````````````````````.0````<````"`````````)P#
M0```````G`,````````@````````````````````!```````````````````
M`$<```#V__]O`@````````#``T```````,`#````````U``````````&````
M``````@```````````````````!1````"P````(`````````F`1```````"8
M!````````!@)````````!P````$````(`````````!@`````````60````,`
M```"`````````+`-0```````L`T````````)!0```````````````````0``
M`````````````````&$```#___]O`@````````"Z$D```````+H2````````
MP@`````````&``````````(``````````@````````!N````_O__;P(`````
M````@!-```````"`$P```````)``````````!P````(````(````````````
M````````?0````0````"`````````!`40```````$!0````````(`0``````
M``8`````````"``````````8`````````(<````$````0@`````````8%4``
M`````!@5````````B`4````````&````%P````@`````````&`````````"1
M`````0````8``````````"!`````````(````````!L`````````````````
M```$````````````````````C`````$````&`````````"`@0```````("``
M``````#``P``````````````````$``````````0`````````)<````!````
M!@````````#@(T```````.`C````````4#H``````````````````!``````
M``````````````"=`````0````8`````````,%Y````````P7@````````T`
M```````````````````$````````````````````HP````$````"````````
M``!@0````````&````````!`/P``````````````````$```````````````
M`````*L````!`````@````````!`GT```````$"?````````Y```````````
M``````````0```````````````````"Y`````0````(`````````**!`````
M```HH````````,`%```````````````````(````````````````````PP``
M``X````#`````````&B]0```````:*T````````(````````````````````
M"``````````(`````````,\````/`````P````````!PO4```````'"M````
M````"`````````````````````@`````````"`````````#;````!@````,`
M````````>+U```````!XK0```````#`"````````!P`````````(````````
M`!``````````Y`````$````#`````````*B_0```````J*\```````!8````
M````````````````"``````````(`````````.D````!`````P``````````
MP$````````"P````````\`$```````````````````@`````````"```````
M``#R`````0````,`````````\,%```````#PL0```````"``````````````
M```````(````````````````````^`````@````#`````````"#"0```````
M$+(```````!($```````````````````(````````````````````/T````!
M````,````````````````````!"R````````*P````````````````````$`
M`````````0`````````!`````P`````````````````````````[L@``````
A``8!```````````````````!````````````````````
